==> aurelia-framework-1.0.0-rc.1.0.2.jar: META-INF/resources/webjars/aurelia-framework/1.0.0-rc.1.0.2/doc/article/en-US/getting-help.md <==
---
{
  "name": "Getting Help",
  "culture": "en-US",
  "description": "As you begin to learn Aurelia and build applications, you may find that you need assistance from time to time. Sometimes it may only be an answer to a quick question or a clarification on the docs. Other times it may be a need for more extensive support, architectural advice or even consulting or training.",
  "engines" : { "aurelia-doc" : "^1.0.0" },
  "author": {
  	"name": "Rob Eisenberg",
  	"url": "http://robeisenberg.com"
  },
  "contributors": [],
  "translators": [],
  "keywords": ["Help", "Support", "Training", "Community"]
}
---
## [Channels](aurelia-doc://section/1/version/1.0.0)

When you join the Aurelia community, you have access to our entire ecosystem. If you need quick help or an answer clarifying documentation, we hope you'll engage with the community in our Gitter chat room. We have one of the most active Gitter channels in the world, with core team and community members present almost every hour of the day, no matter what part of the world you live in. You can join the channel and get help at [http://www.gitter.im/aurelia/discuss](http://www.gitter.im/aurelia/discuss)

If you need architectural advice, consulting or training, you can take advantage of Durandal Inc's services as well as those provided by our global partner network. For inquiries, please contact [consulting@durandal.io](email:consulting@durandal.io). We would love to connect with you, hear your needs and help provide you with the best resources to build your product and business.

If you need commercial or enterprise support, priority bug fixes and/or a guaranteed SLA on support answers for your team or organization, Durandal Inc. can provide for you. To inquire about establishing a support agreement, please contact [support@durandal.io](email:support@durandal.io).

==> aurelia-framework-1.0.3.jar: META-INF/resources/webjars/aurelia-framework/1.0.3/doc/article/en-US/getting-help.md <==
---
{
  "name": "Getting Help",
  "culture": "en-US",
  "description": "As you begin to learn Aurelia and build applications, you may find that you need assistance from time to time. Sometimes it may only be an answer to a quick question or a clarification on the docs. Other times it may be a need for more extensive support, architectural advice or even consulting or training.",
  "engines" : { "aurelia-doc" : "^1.0.0" },
  "author": {
  	"name": "Rob Eisenberg",
  	"url": "http://robeisenberg.com"
  },
  "contributors": [],
  "translators": [],
  "keywords": ["Help", "Support", "Training", "Community"]
}
---
## [Channels](aurelia-doc://section/1/version/1.0.0)

When you join the Aurelia community, you have access to our entire ecosystem. If you need quick help or an answer clarifying documentation, we hope you'll engage with the community in our Gitter chat room. We have one of the most active Gitter channels in the world, with core team and community members present almost every hour of the day, no matter what part of the world you live in. You can join the channel and get help at [http://www.gitter.im/aurelia/discuss](http://www.gitter.im/aurelia/discuss)

If you need architectural advice, consulting or training, you can take advantage of Blue Spire's services as well as those provided by our global partner network. For inquiries, please contact [consulting@bluespire.com](email:consulting@bluespire.com). We would love to connect with you, hear your needs and help provide you with the best resources to build your product and business.

If you need enterprise support, priority bug fixes and/or a guaranteed SLA on support answers for your team or organization, Blue Spire can help you. To inquire about establishing a support agreement, please contact [support@bluespire.com](email:support@bluespire.com).
